timeseria.units
===============

.. automodule:: timeseria.units

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Unit
      TimeUnit
      
   
   

   
   
   



